==> lxqt-powermanagement_0.16.0.orig.tar.xz: lxqt-powermanagement-0.16.0/src/translations/lxqt-powermanagement_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Tomt</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Utlader</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Fullt oppladet</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Lader</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium jernfosfat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Blyakkumulator</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nikkel kadmium</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nickel metallhydrid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Ukjent</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>PDAs batteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Uavbrytelig strømforsynings batteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Primærbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Musbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Tastaturbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Tastaturets og musens batteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Kamerabatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Telefonbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Skjermbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Ukjent batteri</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Batteriinfo</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Strømstyring</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatur:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Tilstand:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Designet maks energi:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Maks energi:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Energi nå:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Energirate:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Teknologi:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Spenning:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Produsent:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Ikke noe batteri!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt kunne ikke finne data om noe batteri - styring ble skrudd av</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>Lite strøm!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Hvile om %n sekund</numerusform>
            <numerusform>Hvile om %n sekunder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Dvale om %n sekund</numerusform>
            <numerusform>Dvale om %n sekunder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Skrur av om %n sekund</numerusform>
            <numerusform>Skrur av om %n sekunder</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Strømstyring</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Du kjører LXQt strømstyring for første gang.
Du kan konfigurere det fra innstillinger... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Konfigurer...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="61"/>
        <source>Configure</source>
        <translation>Konfigurer</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="63"/>
        <location filename="../trayicon.cpp" line="94"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="65"/>
        <source>Disable icon</source>
        <translation>Skru av symbol</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="95"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;LXQt strømstyring&lt;/b&gt;&lt;br/&gt;  - strømstyring for LXQt skrivebordsmiljøet&lt;/p&gt;&lt;p&gt;  Opphavsmenn:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - og andre fra Razor-Qt og LXQt prosjektene&lt;/p&gt;&lt;p&gt;  Opphavsrett &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>LXQt Power Management info</source>
        <translation>LXQt strømstyringsinfo</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="114"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>LXQt strømstyringssymbolet for systemtrauet kan skrus på (igjen) i &lt;i&gt;LXQt strømstyringsinnstillinger&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="116"/>
        <source>Configure now</source>
        <translation>Konfigurer nå</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_0.17.1.orig.tar.xz: lxqt-powermanagement-0.17.1/src/translations/lxqt-powermanagement_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Tomt</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Utlader</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Fullt oppladet</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Lader</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium jernfosfat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Blyakkumulator</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nikkel kadmium</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nickel metallhydrid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Ukjent</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>PDAs batteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Uavbrytelig strømforsynings batteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Primærbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Musbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Tastaturbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Tastaturets og musens batteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Kamerabatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Telefonbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Skjermbatteri</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Ukjent batteri</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Batteriinfo</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Strømstyring</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatur:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Tilstand:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Designet maks energi:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Maks energi:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Energi nå:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Energirate:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Teknologi:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Spenning:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Produsent:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Ikke noe batteri!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt kunne ikke finne data om noe batteri - styring ble skrudd av</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>Lite strøm!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Hvile om %n sekund</numerusform>
            <numerusform>Hvile om %n sekunder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Dvale om %n sekund</numerusform>
            <numerusform>Dvale om %n sekunder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Skrur av om %n sekund</numerusform>
            <numerusform>Skrur av om %n sekunder</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Handling for på/av-knapp</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Handling for hviletast</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Handling for dvaletast</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Strømstyring</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Du kjører LXQt strømstyring for første gang.
Du kan konfigurere det fra innstillinger... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Konfigurer...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="60"/>
        <source>Configure</source>
        <translation>Konfigurer</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="62"/>
        <location filename="../trayicon.cpp" line="93"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="64"/>
        <source>Disable icon</source>
        <translation>Skru av symbol</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;LXQt strømstyring&lt;/b&gt;&lt;br/&gt;  - strømstyring for LXQt skrivebordsmiljøet&lt;/p&gt;&lt;p&gt;  Opphavsmenn:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - og andre fra Razor-Qt og LXQt prosjektene&lt;/p&gt;&lt;p&gt;  Opphavsrett &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="112"/>
        <source>LXQt Power Management info</source>
        <translation>LXQt strømstyringsinfo</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>LXQt strømstyringssymbolet for systemtrauet kan skrus på (igjen) i &lt;i&gt;LXQt strømstyringsinnstillinger&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="115"/>
        <source>Configure now</source>
        <translation>Konfigurer nå</translation>
    </message>
</context>
</TS>
